EXPORTS
	?InsertLinkL@CESMRRichTextViewer@@QAEXPAVCESMRRichTextLink@@H@Z @ 1 NONAME ; void CESMRRichTextViewer::InsertLinkL(class CESMRRichTextLink *, int)
	??1CMRBackground@@UAE@XZ @ 2 NONAME ; CMRBackground::~CMRBackground(void)
	?LatestOperationResult@CMRAttachmentUi@@QAE?AVTAttachmentOpResult@@XZ @ 3 NONAME ; class TAttachmentOpResult CMRAttachmentUi::LatestOperationResult(void)
	?RowHeight@CESMRRichTextViewer@@QAEHXZ @ 4 NONAME ; int CESMRRichTextViewer::RowHeight(void)
	?SetListObserver@CESMRRichTextViewer@@QAEXPAVMESMRListObserver@@@Z @ 5 NONAME ; void CESMRRichTextViewer::SetListObserver(class MESMRListObserver *)
	?RestoreMiddleSoftKeyL@CESMRField@@IAEXXZ @ 6 NONAME ; void CESMRField::RestoreMiddleSoftKeyL(void)
	?DynInitMenuPaneL@CESMRField@@UAEXHPAVCEikMenuPane@@@Z @ 7 NONAME ; void CESMRField::DynInitMenuPaneL(int, class CEikMenuPane *)
	?FieldMode@CESMRField@@QBE?AW4TESMRFieldMode@@XZ @ 8 NONAME ; enum TESMRFieldMode CESMRField::FieldMode(void) const
	?ConstructL@CESMRField@@QAEXPAVCCoeControl@@@Z @ 9 NONAME ; void CESMRField::ConstructL(class CCoeControl *)
	?ApplyLayoutChangesL@CESMRRichTextViewer@@QAEXXZ @ 10 NONAME ; void CESMRRichTextViewer::ApplyLayoutChangesL(void)
	?InitializeL@CESMRField@@UAEXXZ @ 11 NONAME ; void CESMRField::InitializeL(void)
	?Draw@CMRBackground@@MBEXAAVCWindowGc@@ABVCCoeControl@@ABVTRect@@@Z @ 12 NONAME ; void CMRBackground::Draw(class CWindowGc &, class CCoeControl const &, class TRect const &) const
	?GetSelectedLink@CESMRRichTextViewer@@QBEPBVCESMRRichTextLink@@XZ @ 13 NONAME ; class CESMRRichTextLink const * CESMRRichTextViewer::GetSelectedLink(void) const
	?FieldViewMode@CESMRField@@QBE?AW4TESMRFieldType@@XZ @ 14 NONAME ; enum TESMRFieldType CESMRField::FieldViewMode(void) const
	?FocusChanged@CESMRRichTextViewer@@UAEXW4TDrawNow@@@Z @ 15 NONAME ; void CESMRRichTextViewer::FocusChanged(enum TDrawNow)
	?HandlePointerEventL@CESMRField@@MAEXABUTPointerEvent@@@Z @ 16 NONAME ; void CESMRField::HandlePointerEventL(struct TPointerEvent const &)
	??1CESMREditor@@UAE@XZ @ 17 NONAME ; CESMREditor::~CESMREditor(void)
	?NewL@CESMRRichTextViewer@@SAPAV1@PBVCCoeControl@@@Z @ 18 NONAME ; class CESMRRichTextViewer * CESMRRichTextViewer::NewL(class CCoeControl const *)
	?SetListObserver@CESMRField@@UAEXPAVMESMRListObserver@@@Z @ 19 NONAME ; void CESMRField::SetListObserver(class MESMRListObserver *)
	?SetFocusRect@CESMRField@@QAEXABVTRect@@@Z @ 20 NONAME ; void CESMRField::SetFocusRect(class TRect const &)
	?HandleTactileFeedbackL@CESMRField@@IAEXXZ @ 21 NONAME ; void CESMRField::HandleTactileFeedbackL(void)
	?SetFocusLink@CESMRRichTextViewer@@QAEXH@Z @ 22 NONAME ; void CESMRRichTextViewer::SetFocusLink(int)
	?HasOutlineFocus@CESMRField@@QBEHXZ @ 23 NONAME ; int CESMRField::HasOutlineFocus(void) const
	?RowHeight@CESMREditor@@QAEHXZ @ 24 NONAME ; int CESMREditor::RowHeight(void)
	?ComponentControl@CESMRField@@UBEPAVCCoeControl@@H@Z @ 25 NONAME ; class CCoeControl * CESMRField::ComponentControl(int) const
	?SetObserver@CMRAttachmentUi@@QAEXAAVMMRAttachmentUiObserver@@@Z @ 26 NONAME ; void CMRAttachmentUi::SetObserver(class MMRAttachmentUiObserver &)
	?PositionChanged@CESMREditor@@UAEXXZ @ 27 NONAME ; void CESMREditor::PositionChanged(void)
	?NotifyEventL@CESMRField@@IAEXH@Z @ 28 NONAME ; void CESMRField::NotifyEventL(int)
	?NotifyEventL@CESMRField@@IAEXABVMESMRFieldEvent@@@Z @ 29 NONAME ; void CESMRField::NotifyEventL(class MESMRFieldEvent const &)
	?ChangeMiddleSoftKeyL@CESMRField@@QAEXHH@Z @ 30 NONAME ; void CESMRField::ChangeMiddleSoftKeyL(int, int)
	?Type@CESMRRichTextLink@@QBE?AW4TType@1@XZ @ 31 NONAME ; enum CESMRRichTextLink::TType CESMRRichTextLink::Type(void) const
	?NotifyEventAsyncL@CESMRField@@IAEXH@Z @ 32 NONAME ; void CESMRField::NotifyEventAsyncL(int)
	?SetValidatorL@CESMRField@@UAEXPAVMESMRFieldValidator@@@Z @ 33 NONAME ; void CESMRField::SetValidatorL(class MESMRFieldValidator *)
	?GetLinkTextLC@CESMRRichTextViewer@@QBEPAVHBufC16@@ABVCESMRRichTextLink@@@Z @ 34 NONAME ; class HBufC16 * CESMRRichTextViewer::GetLinkTextLC(class CESMRRichTextLink const &) const
	?GetFocusRect@CESMRField@@QBE?AVTRect@@XZ @ 35 NONAME ; class TRect CESMRField::GetFocusRect(void) const
	?OfferKeyEventL@CESMRField@@UAE?AW4TKeyResponse@@ABUTKeyEvent@@W4TEventCode@@@Z @ 36 NONAME ; enum TKeyResponse CESMRField::OfferKeyEventL(struct TKeyEvent const &, enum TEventCode)
	?LockL@CESMRField@@UAEXXZ @ 37 NONAME ; void CESMRField::LockL(void)
	?InternalizeL@CESMRField@@UAEXAAVMESMRCalEntry@@@Z @ 38 NONAME ; void CESMRField::InternalizeL(class MESMRCalEntry &)
	?SetEventQueueL@CESMRField@@UAEXPAVMESMRFieldEventQueue@@@Z @ 39 NONAME ; void CESMRField::SetEventQueueL(class MESMRFieldEventQueue *)
	?CurrentItemIndex@CESMRField@@QBEHXZ @ 40 NONAME ; int CESMRField::CurrentItemIndex(void) const
	?ChangeMiddleSoftKeyL@CESMRField@@IAEXH@Z @ 41 NONAME ; void CESMRField::ChangeMiddleSoftKeyL(int)
	?ClearSelectionAndSetTextL@CESMREditor@@QAEXABVTDesC16@@@Z @ 42 NONAME ; void CESMREditor::ClearSelectionAndSetTextL(class TDesC16 const &)
	?NewL@CESMRRichTextLink@@SAPAV1@HHABVTDesC16@@W4TType@1@W4TTriggerKey@1@@Z @ 43 NONAME ; class CESMRRichTextLink * CESMRRichTextLink::NewL(int, int, class TDesC16 const &, enum CESMRRichTextLink::TType, enum CESMRRichTextLink::TTriggerKey)
	?SetLinkObserver@CESMRRichTextViewer@@QAEXPAVMESMRRichTextObserver@@@Z @ 44 NONAME ; void CESMRRichTextViewer::SetLinkObserver(class MESMRRichTextObserver *)
	?OkToLoseFocusL@CESMRField@@UAEHW4TESMREntryFieldId@@@Z @ 45 NONAME ; int CESMRField::OkToLoseFocusL(enum TESMREntryFieldId)
	?SetFieldViewMode@CESMRField@@QAEXW4TESMRFieldType@@@Z @ 46 NONAME ; void CESMRField::SetFieldViewMode(enum TESMRFieldType)
	?MinimumSize@CESMRField@@UAE?AVTSize@@XZ @ 47 NONAME ; class TSize CESMRField::MinimumSize(void)
	?HandleLongtapEventL@CESMRField@@MAEXABVTPoint@@@Z @ 48 NONAME ; void CESMRField::HandleLongtapEventL(class TPoint const &)
	??0CESMRField@@IAE@XZ @ 49 NONAME ; CESMRField::CESMRField(void)
	?SetLineSpacingL@CESMRRichTextViewer@@QAEXH@Z @ 50 NONAME ; void CESMRRichTextViewer::SetLineSpacingL(int)
	?SetFontL@CESMREditor@@QAEXPBVCFont@@@Z @ 51 NONAME ; void CESMREditor::SetFontL(class CFont const *)
	?IsLocked@CESMRField@@QAEHXZ @ 52 NONAME ; int CESMRField::IsLocked(void)
	?DefaultText@CESMREditor@@QAEABVTDesC16@@XZ @ 53 NONAME ; class TDesC16 const & CESMREditor::DefaultText(void)
	?SetListObserver@CESMREditor@@QAEXPAVMESMRListObserver@@@Z @ 54 NONAME ; void CESMREditor::SetListObserver(class MESMRListObserver *)
	?LaunchFetchUi@CMRAttachmentUi@@QAEHAAVMESMRCalEntry@@@Z @ 55 NONAME ; int CMRAttachmentUi::LaunchFetchUi(class MESMRCalEntry &)
	?SetOutlineFocusL@CESMRField@@UAEXH@Z @ 56 NONAME ; void CESMRField::SetOutlineFocusL(int)
	?ExternalizeL@CESMRField@@UAEXAAVMESMRCalEntry@@@Z @ 57 NONAME ; void CESMRField::ExternalizeL(class MESMRCalEntry &)
	?FontChangedL@CESMRField@@UAEXXZ @ 58 NONAME ; void CESMRField::FontChangedL(void)
	?SizeChanged@CESMRField@@UAEXXZ @ 59 NONAME ; void CESMRField::SizeChanged(void)
	?CurrentLineNumber@CESMREditor@@QAEHXZ @ 60 NONAME ; int CESMREditor::CurrentLineNumber(void)
	?SetPreItemIndex@CESMRField@@QAEXH@Z @ 61 NONAME ; void CESMRField::SetPreItemIndex(int)
	?HandleFieldEventL@CESMRField@@MAEXABVMESMRFieldEvent@@@Z @ 62 NONAME ; void CESMRField::HandleFieldEventL(class MESMRFieldEvent const &)
	?CurrentLineNumber@CESMRRichTextViewer@@QAEHXZ @ 63 NONAME ; int CESMRRichTextViewer::CurrentLineNumber(void)
	?OfferKeyEventL@CESMRRichTextViewer@@UAE?AW4TKeyResponse@@ABUTKeyEvent@@W4TEventCode@@@Z @ 64 NONAME ; enum TKeyResponse CESMRRichTextViewer::OfferKeyEventL(struct TKeyEvent const &, enum TEventCode)
	?LineCount@CESMREditor@@QBEHXZ @ 65 NONAME ; int CESMREditor::LineCount(void) const
	?SetFocusType@CESMRField@@QAEXW4TESMRFieldFocusType@@@Z @ 66 NONAME ; void CESMRField::SetFocusType(enum TESMRFieldFocusType)
	?SetFieldId@CESMRField@@UAEXW4TESMREntryFieldId@@@Z @ 67 NONAME ; void CESMRField::SetFieldId(enum TESMREntryFieldId)
	?CopyCurrentLinkToClipBoardL@CESMRRichTextViewer@@QBEXXZ @ 68 NONAME ; void CESMRRichTextViewer::CopyCurrentLinkToClipBoardL(void) const
	?FocusChanged@CESMREditor@@UAEXW4TDrawNow@@@Z @ 69 NONAME ; void CESMREditor::FocusChanged(enum TDrawNow)
	?SetDefaultTextL@CESMREditor@@QAEXPAVHBufC16@@@Z @ 70 NONAME ; void CESMREditor::SetDefaultTextL(class HBufC16 *)
	?TriggerKey@CESMRRichTextLink@@QBE?AW4TTriggerKey@1@XZ @ 71 NONAME ; enum CESMRRichTextLink::TTriggerKey CESMRRichTextLink::TriggerKey(void) const
	?LongtapDetectedL@CESMRField@@QAEXABVTPoint@@@Z @ 72 NONAME ; void CESMRField::LongtapDetectedL(class TPoint const &)
	?IsFieldActivated@CESMRField@@QBEHXZ @ 73 NONAME ; int CESMRField::IsFieldActivated(void) const
	?CountComponentControls@CESMRField@@UBEHXZ @ 74 NONAME ; int CESMRField::CountComponentControls(void) const
	?LinkSelectedL@CESMRRichTextViewer@@QAEHXZ @ 75 NONAME ; int CESMRRichTextViewer::LinkSelectedL(void)
	?Value@CESMRRichTextLink@@QBEAAVTDesC16@@XZ @ 76 NONAME ; class TDesC16 & CESMRRichTextLink::Value(void) const
	?PreItemIndex@CESMRField@@QBEHXZ @ 77 NONAME ; int CESMRField::PreItemIndex(void) const
	?AddLinkL@CESMRRichTextViewer@@QAEXPAVCESMRRichTextLink@@@Z @ 78 NONAME ; void CESMRRichTextViewer::AddLinkL(class CESMRRichTextLink *)
	?StartPos@CESMRRichTextLink@@QBEHXZ @ 79 NONAME ; int CESMRRichTextLink::StartPos(void) const
	?NewL@CESMREditor@@SAPAV1@XZ @ 80 NONAME ; class CESMREditor * CESMREditor::NewL(void)
	?SetTextL@CESMRRichTextViewer@@QAEXPBVTDesC16@@H@Z @ 81 NONAME ; void CESMRRichTextViewer::SetTextL(class TDesC16 const *, int)
	?ListObserverSet@CESMRField@@UAEXXZ @ 82 NONAME ; void CESMRField::ListObserverSet(void)
	?ExecuteGenericCommandL@CESMRField@@UAEHH@Z @ 83 NONAME ; int CESMRField::ExecuteGenericCommandL(int)
	?SetTitlePaneObserver@CESMRField@@UAEXPAVMESMRTitlePaneObserver@@@Z @ 84 NONAME ; void CESMRField::SetTitlePaneObserver(class MESMRTitlePaneObserver *)
	?OfferKeyEventL@CESMREditor@@UAE?AW4TKeyResponse@@ABUTKeyEvent@@W4TEventCode@@@Z @ 85 NONAME ; enum TKeyResponse CESMREditor::OfferKeyEventL(struct TKeyEvent const &, enum TEventCode)
	?GetMinimumVisibleVerticalArea@CESMRField@@UAEXAAH0@Z @ 86 NONAME ; void CESMRField::GetMinimumVisibleVerticalArea(int &, int &)
	?GetCursorLineVerticalPos@CESMRField@@UAEXAAH0@Z @ 87 NONAME ; void CESMRField::GetCursorLineVerticalPos(int &, int &)
	?HandleEdwinEventL@CESMREditor@@UAEXPAVCEikEdwin@@W4TEdwinEvent@MEikEdwinObserver@@@Z @ 88 NONAME ; void CESMREditor::HandleEdwinEventL(class CEikEdwin *, enum MEikEdwinObserver::TEdwinEvent)
	?LaunchViewerUi@CMRAttachmentUi@@QAEHAAVMESMRCalEntry@@@Z @ 89 NONAME ; int CMRAttachmentUi::LaunchViewerUi(class MESMRCalEntry &)
	?UpdateExtControlL@CESMRField@@QAEXPAVCCoeControl@@@Z @ 90 NONAME ; void CESMRField::UpdateExtControlL(class CCoeControl *)
	?SetCurrentItemIndex@CESMRField@@QAEXH@Z @ 91 NONAME ; void CESMRField::SetCurrentItemIndex(int)
	?SetEventQueue@CESMRRichTextViewer@@QAEXPAVMESMRFieldEventQueue@@@Z @ 92 NONAME ; void CESMRRichTextViewer::SetEventQueue(class MESMRFieldEventQueue *)
	?HandleRawPointerEventL@CESMRField@@MAEHABUTPointerEvent@@@Z @ 93 NONAME ; int CESMRField::HandleRawPointerEventL(struct TPointerEvent const &)
	?NotifyEventAsyncL@CESMRField@@IAEXPAVMESMRFieldEvent@@@Z @ 94 NONAME ; void CESMRField::NotifyEventAsyncL(class MESMRFieldEvent *)
	?NewL@CESMREditor@@SAPAV1@PBVCCoeControl@@HHH@Z @ 95 NONAME ; class CESMREditor * CESMREditor::NewL(class CCoeControl const *, int, int, int)
	??1CESMRRichTextLink@@UAE@XZ @ 96 NONAME ; CESMRRichTextLink::~CESMRRichTextLink(void)
	?LineCount@CESMRRichTextViewer@@QAEHXZ @ 97 NONAME ; int CESMRRichTextViewer::LineCount(void)
	?FieldId@CESMRField@@UBE?AW4TESMREntryFieldId@@XZ @ 98 NONAME ; enum TESMREntryFieldId CESMRField::FieldId(void) const
	?SetFontL@CESMRRichTextViewer@@QAEXPBVCFont@@@Z @ 99 NONAME ; void CESMRRichTextViewer::SetFontL(class CFont const *)
	??1CESMRRichTextViewer@@UAE@XZ @ 100 NONAME ; CESMRRichTextViewer::~CESMRRichTextViewer(void)
	?SetStartPos@CESMRRichTextLink@@QAEXH@Z @ 101 NONAME ; void CESMRRichTextLink::SetStartPos(int)
	?SetMiddleSoftKeyVisible@CESMRField@@IAEXH@Z @ 102 NONAME ; void CESMRField::SetMiddleSoftKeyVisible(int)
	?NewL@CMRAttachmentUi@@SAPAV1@XZ @ 103 NONAME ; class CMRAttachmentUi * CMRAttachmentUi::NewL(void)
	?CursorLinePos@CESMREditor@@QBEHXZ @ 104 NONAME ; int CESMREditor::CursorLinePos(void) const
	??1CESMRField@@UAE@XZ @ 105 NONAME ; CESMRField::~CESMRField(void)
	?Length@CESMRRichTextLink@@QBEHXZ @ 106 NONAME ; int CESMRRichTextLink::Length(void) const
	?PositionChanged@CESMRRichTextViewer@@UAEXXZ @ 107 NONAME ; void CESMRRichTextViewer::PositionChanged(void)
	??1CMRAttachmentUi@@UAE@XZ @ 108 NONAME ; CMRAttachmentUi::~CMRAttachmentUi(void)
	?GetFocusType@CESMRField@@QBE?AW4TESMRFieldFocusType@@XZ @ 109 NONAME ; enum TESMRFieldFocusType CESMRField::GetFocusType(void) const
	?HandleSingletapEventL@CESMRField@@MAEHABVTPoint@@@Z @ 110 NONAME ; int CESMRField::HandleSingletapEventL(class TPoint const &)
	?SetContainerWindowL@CESMRField@@UAEXABVCCoeControl@@@Z @ 111 NONAME ; void CESMRField::SetContainerWindowL(class CCoeControl const &)
	?EventObserver@CESMRField@@MBEPAVMESMRFieldEventObserver@@XZ @ 112 NONAME ; class MESMRFieldEventObserver * CESMRField::EventObserver(void) const
	?SetMargins@CESMRRichTextViewer@@QAEXH@Z @ 113 NONAME ; void CESMRRichTextViewer::SetMargins(int)
	?NewL@CMRBackground@@SAPAV1@XZ @ 114 NONAME ; class CMRBackground * CMRBackground::NewL(void)
	?GetFocusLink@CESMRRichTextViewer@@QBEHXZ @ 115 NONAME ; int CESMRRichTextViewer::GetFocusLink(void) const
	?GetLimitLength@CESMREditor@@QBEHXZ @ 116 NONAME ; int CESMREditor::GetLimitLength(void) const
	?SetFieldMode@CESMRField@@QAEXW4TESMRFieldMode@@@Z @ 117 NONAME ; void CESMRField::SetFieldMode(enum TESMRFieldMode)
	?ResetActionMenuL@CESMRRichTextViewer@@QBEXXZ @ 118 NONAME ; void CESMRRichTextViewer::ResetActionMenuL(void) const
	?SupportsLongTapFunctionalityL@CESMRField@@UAEHABUTPointerEvent@@@Z @ 119 NONAME ; int CESMRField::SupportsLongTapFunctionalityL(struct TPointerEvent const &)
	?PointerEventOccuresOnALinkL@CESMRRichTextViewer@@QAEHABUTPointerEvent@@@Z @ 120 NONAME ; int CESMRRichTextViewer::PointerEventOccuresOnALinkL(struct TPointerEvent const &)
	?RecordField@CESMRField@@QAEXXZ @ 121 NONAME ; void CESMRField::RecordField(void)
	?Draw@CESMRField@@UBEXABVTRect@@@Z @ 122 NONAME ; void CESMRField::Draw(class TRect const &) const
	?MoveToScreen@CESMRField@@QAEXH@Z @ 123 NONAME ; void CESMRField::MoveToScreen(int)

